======================
PYKAKASI documentation
======================

This is the documentation for Pykakasi library and utility.
pykakasi is a library and utility implemented `KAKASI`_ functionality in Python.
KAKASI was originaly built to convert Japanese text to roman form.

pykakasi is a free software, and available on `GitHub`_ project.

`wakati` is an implementation of kakasi's wakati gaki option.


:ref:`string-options-ref`
    Command line options

:ref:`api-documents-ref`
    Application programming interface and options

:ref:`authors`
    PyKAKASI authors and credits

:ref:`copyright`
    Copyright and license

:ref:`contents`
    Access to all of document contents



Supported python versions
=========================

Pykakasi supports python 2.7, python 3.5, 3.6, 3.7, 3.8 and PyPy.

It may work with python 2.6, 3.3, 3.4 and pypy3 but these are not tested now.


Dependency
==========

It depends on `klepto`_ for providing a mapping database.


About KAKASI
============

`KAKASI`_ is the language processing filter to convert Kanji characters to Hiragana, Katakana or Romaji [#1]_ and
may be helpful to read Japanese documents.

The name "KAKASI" is the abbreviation of "kanji kana simple inverter" and the inverse of SKK "simple kana kanji converter"
which is developed by Masahiko Sato at Tohoku University. The most entries of the kakasi dictionary is derived form the
SKK dictionaries. If you have some interests in the naming of "KAKASI", please consult to Japanese-English dictionary. :-)

.. _`copyright`:

Copyright and License
=====================

Copyright 2010-2019 Hiroshi Miura <miurahr@linux.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


.. _klepto: https://github.com/uqfoundation/klepto
.. _`KAKASI`: http://kakasi.namazu.org/
.. _GitHub: https://github.com/miurahr/pykakasi


.. include:: contents.rst

.. rubric:: Footnotes

.. [#1] "Romaji" is alphabetical description of Japanese pronunciation.
